@@ -20,6 +20,7 @@ from PyFin.api.DateUtilities import makeSchedule
 from PyFin.Analysis import transform
 from PyFin.Analysis.SeriesValues import SeriesValues
 from PyFin.api.Analysis import SIGN
+from PyFin.api.Analysis import AVG
 from PyFin.api.Analysis import EMA
 from PyFin.api.Analysis import MACD
 from PyFin.api.Analysis import RSI
@@ -96,6 +97,7 @@ __all__ = ["datesList",
            "transform",
            "SIGN",
            "SeriesValues",
+           "AVG",
            "EMA",
            "MACD",
            "RSI",
