@@ -12,7 +12,10 @@ import pickle
 import os
 from collections import deque
 import numpy as np
-from PyFin.Math.Accumulators.impl import Deque
+from PyFin.Math.Accumulators.impl import (
+    Deque,
+    DiffDeque
+)
 
 
 class TestAccumulatorImpl(unittest.TestCase):
@@ -55,5 +58,12 @@ class TestAccumulatorImpl(unittest.TestCase):
             caclulated_idx = deque2.idx(max_val)
             self.assertEqual(expected_idx, caclulated_idx)
 
+    def testDiffDequeSum(self):
+        deque = DiffDeque(10)
+        values = [1, 2, 3, 4, 5]
+        stamps = [1, 7, 9, 13, 26]
+
+        deque.dumps(values, stamps)
+        self.assertTrue(deque.sum(), 5)
 
 
