@@ -25,6 +25,10 @@ from PyFin.Math.Accumulators import MovingMin
 from PyFin.Math.Accumulators import MovingArgMin
 from PyFin.Math.Accumulators import MovingRank
 from PyFin.Math.Accumulators import MovingQuantile
+from PyFin.Math.Accumulators import MovingCount
+from PyFin.Math.Accumulators import TimeMovingCount
+from PyFin.Math.Accumulators import MovingCountUnique
+from PyFin.Math.Accumulators import TimeMovingCountUnique
 from PyFin.Math.Accumulators import MovingAllTrue
 from PyFin.Math.Accumulators import MovingAnyTrue
 from PyFin.Math.Accumulators import MovingAverage
@@ -52,6 +56,25 @@ class TestStatefulAccumulators(unittest.TestCase):
         np.random.seed(0)
         self.sample = np.random.randn(10000)
 
+    def testParse(self):
+        exp = TimeMovingCount(10, "x")
+        self.assertEqual(exp.window, 10)
+
+        exp = TimeMovingCount(12., "x")
+        self.assertEqual(exp.window, 12)
+
+        exp = TimeMovingCount("2D", "x")
+        self.assertEqual(exp.window, 2. * 24 * 3600)
+
+        exp = TimeMovingCount("3H", "x")
+        self.assertEqual(exp.window, 3. * 3600)
+
+        exp = TimeMovingCount("4T", "x")
+        self.assertEqual(exp.window, 4. * 60)
+
+        exp = TimeMovingCount("5S", "x")
+        self.assertEqual(exp.window, 5.)
+
     def testCurrentValueHolderWithOtherValueHolder(self):
         test1 = Exp(Current('x'))
         test1.push({'x': 2.0})
@@ -785,9 +808,71 @@ class TestStatefulAccumulators(unittest.TestCase):
             self.assertAlmostEqual(test.value, pickled.value)
         os.unlink(f.name)
 
+    def testMovingCount(self):
+        window = 10
+        mat = MovingCount(window, Latest('x'))
+        total = np.random.randn(2500)
+        con = deque(maxlen=window)
+        for i, value in enumerate(total):
+            value = float(value)
+            con.append(value)
+            mat.push(dict(x=value))
+
+            calculated = mat.result()
+            expected = len(con)
+            self.assertEqual(calculated, expected, "at index {0}\n"
+                                                   "expected:   {1}\n"
+                                                   "calculated: {2}".format(i, expected, calculated))
+
+    def testTimeMovingCount(self):
+        window = 60
+        mat = TimeMovingCount(window, Latest("x"))
+        values = np.random.randn(2500)
+        stamps = np.cumsum(np.random.randint(0, 10, 2500))
+        for i, (value, stamp) in enumerate(zip(values, stamps)):
+            mat.push(dict(x=value, stamp=stamp))
+
+            calculated = mat.result()
+            time_diff = (stamp - stamps) < window
+            expected = np.sum(time_diff[:i+1])
+            self.assertEqual(calculated, expected, "at index {0}\n"
+                                                   "expected:   {1}\n"
+                                                   "calculated: {2}".format(i, expected, calculated))
+
+    def testMovingCountUnique(self):
+        window = 10
+        mat = MovingCountUnique(window, Latest('x'))
+        total = np.random.randint(0, 10, 2500)
+        con = deque(maxlen=window)
+        for i, value in enumerate(total):
+            value = float(value)
+            con.append(value)
+            mat.push(dict(x=value))
+
+            calculated = mat.result()
+            expected = len(np.unique(con))
+            self.assertEqual(calculated, expected, "at index {0}\n"
+                                                   "expected:   {1}\n"
+                                                   "calculated: {2}".format(i, expected, calculated))
+
+    def testTimeMovingCountUnique(self):
+        window = 60
+        mat = TimeMovingCountUnique(window, Latest("x"))
+        values = np.random.randint(0, 10, 2500)
+        stamps = np.cumsum(np.random.randint(0, 10, 2500))
+        for i, (value, stamp) in enumerate(zip(values, stamps)):
+            mat.push(dict(x=value, stamp=stamp))
+
+            calculated = mat.result()
+            time_diff = (stamp - stamps) < window
+            time_diff[i+1:] = False
+            expected = len(np.unique(values[time_diff]))
+            self.assertEqual(calculated, expected, "at index {0}\n"
+                                                   "expected:   {1}\n"
+                                                   "calculated: {2}".format(i, expected, calculated))
+
     def testMovingAllTrue(self):
         window = 3
-
         underlying = Latest('x') > 0.
 
         mat = MovingAllTrue(window, underlying)
